pub struct ConditionalLogit;Expand description
Conditional Logit (Chamberlain’s fixed-effects logit).
Conditions on the sum of y within each group, eliminating the group FE. Only groups with variation in y contribute to the likelihood.
Implementations
Sourceimpl ConditionalLogit
impl ConditionalLogit
Sourcepub fn fit(
y: &ArrayBase<OwnedRepr<f64>, Dim<[usize; 1]>>,
x: &ArrayBase<OwnedRepr<f64>, Dim<[usize; 2]>>,
groups: &[usize],
) -> Result<ConditionalResult, GreenersError>
pub fn fit( y: &ArrayBase<OwnedRepr<f64>, Dim<[usize; 1]>>, x: &ArrayBase<OwnedRepr<f64>, Dim<[usize; 2]>>, groups: &[usize], ) -> Result<ConditionalResult, GreenersError>
Fit conditional logit.
groups: group ID for each observation.
pub fn fit_with_names( y: &ArrayBase<OwnedRepr<f64>, Dim<[usize; 1]>>, x: &ArrayBase<OwnedRepr<f64>, Dim<[usize; 2]>>, groups: &[usize], variable_names: Option<Vec<String>>, ) -> Result<ConditionalResult, GreenersError>