pub struct FixedEffects;Implementations
Sourceimpl FixedEffects
impl FixedEffects
Sourcepub fn from_formula<T>(
formula: &Formula,
data: &DataFrame,
entity_ids: &[T],
) -> Result<PanelResult, GreenersError>
pub fn from_formula<T>( formula: &Formula, data: &DataFrame, entity_ids: &[T], ) -> Result<PanelResult, GreenersError>
Estimates Fixed Effects model using a formula and DataFrame. Requires entity_ids to be passed separately.
Sourcepub fn from_formula_with_cov<T>(
formula: &Formula,
data: &DataFrame,
entity_ids: &[T],
cov_type: CovarianceType,
) -> Result<PanelResult, GreenersError>
pub fn from_formula_with_cov<T>( formula: &Formula, data: &DataFrame, entity_ids: &[T], cov_type: CovarianceType, ) -> Result<PanelResult, GreenersError>
Estimates Fixed Effects model with a specified covariance type.
Sourcepub fn fit<T>(
y: &ArrayBase<OwnedRepr<f64>, Dim<[usize; 1]>>,
x: &ArrayBase<OwnedRepr<f64>, Dim<[usize; 2]>>,
groups: &[T],
) -> Result<PanelResult, GreenersError>
pub fn fit<T>( y: &ArrayBase<OwnedRepr<f64>, Dim<[usize; 1]>>, x: &ArrayBase<OwnedRepr<f64>, Dim<[usize; 2]>>, groups: &[T], ) -> Result<PanelResult, GreenersError>
Fits the Fixed Effects model using Within Estimation.
Arguments
y- Dependent variable.x- Regressors (DO NOT includes a constant/intercept column!).groups- Vector of Entity IDs (Integers, Strings, etc.) corresponding to rows.
pub fn fit_with_names<T>( y: &ArrayBase<OwnedRepr<f64>, Dim<[usize; 1]>>, x: &ArrayBase<OwnedRepr<f64>, Dim<[usize; 2]>>, groups: &[T], variable_names: Option<Vec<String>>, cov_type: CovarianceType, ) -> Result<PanelResult, GreenersError>